'use strict';

var gitbook = require('../gitbook');
var encodeSummary = require('./encodeSummary');
var encodeGlossary = require('./encodeGlossary');
var encodeReadme = require('./encodeReadme');
var encodeLanguages = require('./encodeLanguages');
var encodePage = require('./encodePage');
var encodeFile = require('./encodeFile');

/**
 * Encode context to JSON from an output instance.
 * This JSON representation is used as initial state for the redux store.
 *
 * @param  {Output} output
 * @param  {Page} page?
 * @return {JSON}
 */
function encodeStateToJSON(output, page) {
    var book = output.getBook();
    var urls = output.getURLIndex();

    return {
        output: {
            name: output.getGenerator()
        },
        gitbook: {
            version: gitbook.version,
            time: gitbook.START_TIME
        },

        summary: encodeSummary(book.getSummary(), urls),
        glossary: encodeGlossary(book.getGlossary(), urls),
        readme: encodeReadme(book.getReadme(), urls),
        config: book.getConfig().getValues().toJS(),
        languages: book.isMultilingual() ? encodeLanguages(book.getLanguages(), book.getLanguage(), urls) : undefined,

        page: page ? encodePage(page, book.getSummary(), urls) : undefined,
        file: page ? encodeFile(page.getFile(), urls) : undefined
    };
}

module.exports = encodeStateToJSON;
//# sourceMappingURL=encodeState.js.map