'use strict';

var lookupStructureFile = require('./lookupStructureFile');
var readmeFromDocument = require('./readmeFromDocument');
var error = require('../utils/error');

/**
 * Parse readme from book.
 *
 * @param {Book} book
 * @return {Promise<Book>}
 */
function parseReadme(book) {
    var logger = book.logger;

    var fs = book.getContentFS();

    return lookupStructureFile(book, 'readme').then(function (file) {
        if (!file) {
            throw new error.FileNotFoundError({ filename: 'README' });
        }

        logger.debug.ln('readme found at ' + file.path);
        return file.parse(fs).then(function (document) {
            var readme = readmeFromDocument(document);
            readme = readme.setFile(file);
            return book.set('readme', readme);
        });
    });
}

module.exports = parseReadme;
//# sourceMappingURL=parseReadme.js.map